Clazz.declarePackage("J.api");
(function(){
var c$ = Clazz.declareInterface(J.api, "JmolScriptManager");
})();
;//5.0.1-v7 Mon Jan 19 16:49:55 CST 2026
